# -*- coding: utf-8 -*-
# This file is part of the investment-module from m-ds for Tryton.
# The COPYRIGHT file at the top level of this repository contains the
# full copyright notices and license terms.

from trytond.model import fields
from trytond.pool import PoolMeta, Pool


class Asset(metaclass=PoolMeta):
    __name__ = 'investment.asset'

    chart_img = fields.Function(fields.Binary(
        string='Chart', readonly=True),
        'on_change_with_chart_img')
    chart_reference = fields.One2Many(
        string='Chart Image',
        states={'invisible': True}, readonly=True,
        model_name='investment_chart.img', field='asset', size=1)

    @fields.depends('chart_reference')
    def on_change_with_chart_img(self, name=None):
        """ get image
        """
        if self.chart_reference:
            return self.chart_reference[0].imgdata

    @classmethod
    def after_update_actions(cls, assets):
        """ run activities after rate-update
        """
        Chart = Pool().get('investment_chart.img')

        super(Asset, cls).after_update_actions(assets)
        Chart.update_chart_images(assets)

# end Asset
